==> haskell-path-io-1.8.2-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-9mF5VzZJCjhFlKKmaypj4I
key:                  path-io-1.8.2-9mF5VzZJCjhFlKKmaypj4I
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  7062f413be40898a95578459efdc6cd1
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-9mF5VzZJCjhFlKKmaypj4I
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN exceptions-0.10.5 filepath-1.4.2.2
    path-0.9.5-XzRPSWXxBICauznS9uWSO
    temporary-1.3-3NOXbZBNm6jw25HF8dLG0 time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-KxuMsRfldAv3o1PX9QN6ga

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.8.2-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-HtbZrzZsc3K9gwRxRjYoYf
key:                  path-io-1.8.2-HtbZrzZsc3K9gwRxRjYoYf
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  c68f99dbe2b1c933c152215c0f368582
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-HtbZrzZsc3K9gwRxRjYoYf
depends:
    base-4.17.2.1 containers-0.6.7 directory-1.3.7.1
    dlist-1.0-BKgPi70fx5AJreCYiKxIIN exceptions-0.10.5 filepath-1.4.2.2
    path-0.9.5-Ig6S8vSh2cyH5PaA70NGjA
    temporary-1.3-BUD9rQS749x5bLVTfwQ4gp time-1.12.2
    transformers-0.5.6.2 unix-compat-0.7.4.1-7O49sxXSp3B9cDegRW2Oej

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
